#define VERSION		"0.01"
#define NAME		"q2-wrapper"
#define YEAR		"1998"
#define AUTHOR		"David Griffith"
#define EMAIL		"dgriffi@ultrix6.cs.csubak.edu"

#define SOFT		0
#define SOFTX		1
#define	GL		2
#define	GLX		3

#define LINELEN        200	/* max length of command line */
#define ERRLEN		80	/* length of an error message */
#define PATHLEN         50	/* max length of a path */
#define RENDLEN         8	/* rendering lib name maxlength */
#define DEV_PATHLEN	15
#define HOMEPATHLEN	20


/* Used with quit_verbosity.  Set quit_verbosity before calling exit(3). */
#define TERSE_QUIT	0	/* Output nothing on exit. */
#define SMALL_QUIT	1	/* ==== Q2-wrapper exiting ==== */
#define BIG_QUIT	2	/* SMALL_QUIT plus greeting() */

/* Returned by checkdisplay() and used to determine whether to */ 
/* become superuser again. */
#define REF_SOFT	0
#define REF_GL		1
#define REF_SOFTX	2
#define REF_GLX		3
#define REF_GGI		4	/* Zoid says he's working on this one. */

struct commandline {
        char vid_ref[RENDLEN+1];
        char basedir[PATHLEN+1];
        char cddir[PATHLEN+1];
        char cd_dev[DEV_PATHLEN+1];
};

struct directories {
	char home[PATHLEN+1];
	char dot[PATHLEN+1];
	char save[PATHLEN+1];
	char pic[PATHLEN+1];
	char demo[PATHLEN+1];
	char players[PATHLEN+1];
	char video[PATHLEN+1];
};


extern struct commandline line;
/* extern struct directories dir; */

extern int	quit_verbosity;


/************************************************************************
 *									*
 * Function Prototypes							*
 *									*
 ************************************************************************/

void greetings(void);
/*
 * Spew some greetings
 *
 ************************************************************************/

void die(void);
/*
 * Print "==== Q2-wrapper exiting ====" really nicely.  Never returns.
 *
 ************************************************************************/

void usage(char *);
/*
 * Print usage message.  Never returns.
 * 
 * Parameters:
 * 	1.  argv[0]
 *	2.  0 if terse, 1 if verbose.
 * 
 ************************************************************************/

void makeline(char *);
/*
 * Convert the command line struct into the actual string passed to the
 * quake2 binary.
 *
 ************************************************************************/

/*int checkdisplay(struct commandline *); */
int checkdisplay(void);
/*
 * Check if we're in X11 or SVGALIB.  
 *
 * Return values:
 *		REF_SOFT	Software rendering on the console.
 *		REF_GL		OpenGL rendering on the console
 *		REF_SOFTX	Software rendering in X11
 *		REF_GLX		OpenGL rendering in X11 (not supported yet)
 *		REF_GGI		GGI rendering (not supported yet)
 *
 ************************************************************************/

int getpaths(void);
/*
 * Load up struct directories dir with paths and stuff.  Should be done
 * before creating .quake2/ and friends, manipulating stuff in
 * BASEDIR/SYS-BASE or .quake2/
 *
 * Return values:
 *	1	$HOME exists.
 *	-1	$HOME doesn't exist.  This shouldn't happen.
 *
 ************************************************************************/

int checkdirs(void);
/* 
 * See if the q2-wrapper directories exist.  If not, make them.  It's
 * important to create these directories explicitly, otherwise Quake2 will
 * create them in basedir and muck up everything. 
 *
 * ln -s BASEDIR/sys-baseq2/players/male $HOME/.quake2/players/male
 * ln -s BASEDIR/sys-baseq2/players/female $HOME/.quake2/players/female
 *
 * The above allows the user to use the system skins (which are
 * unchangable by lusers) AND have his own skins in
 * $HOME/.quake2/players/<foo>/.
 *
 * If any of these directories or symlinks are removed, they are recreated
 * the next time q2-wrapper is run.
 *
 * Return values:
 *	1	$HOME/.quake2 exists and the contents make sense.
 *	-1	Doesn't make sense.  
 *
 ************************************************************************/

int makelinks(void);
/*
 * Instead of saves, screenshots, etc being in BASEDIR/baseq2, they'll be
 * in $HOME/.quake2 instead.  This and breaklinks are seperate
 * functions because some day I may want to doing more stuff in here.
 *
 * ln -s $HOME/.quake2 BASEDIR/baseq2
 *
 * Return values:
 *	1	Linkup went okay.
 *	-1	Something went wrong.
 *
 ************************************************************************/

int breaklinks(void);
/*
 * These symlinks must be removed for the next player to use his own
 * settings.  No, I'm not doing system("rm -f blahblah");
 *
 * rm -f BASEDIR/baseq2
 *
 * Return values:
 *	1	Went okay.
 *	-1	Something went wrong.
 *
 ************************************************************************/

